@@ -17,10 +17,11 @@ import qualified Utility.CoProcess as CoProcess
 type HashObjectHandle = CoProcess.CoProcessHandle
 
 hashObjectStart :: Repo -> IO HashObjectHandle
-hashObjectStart = gitCoProcessStart
+hashObjectStart = CoProcess.rawMode <=< gitCoProcessStart True
 	[ Param "hash-object"
 	, Param "-w"
 	, Param "--stdin-paths"
+	, Param "--no-filters"
 	]
 
 hashObjectStop :: HashObjectHandle -> IO ()
@@ -29,17 +30,17 @@ hashObjectStop = CoProcess.stop
 {- Injects a file into git, returning the Sha of the object. -}
 hashFile :: HashObjectHandle -> FilePath -> IO Sha
 hashFile h file = CoProcess.query h send receive
-	where
-		send to = do
-			fileEncoding to
-			hPutStrLn to file
-		receive from = getSha "hash-object" $ hGetLine from
+  where
+	send to = hPutStrLn to file
+	receive from = getSha "hash-object" $ hGetLine from
 
 {- Injects some content into git, returning its Sha. -}
 hashObject :: ObjectType -> String -> Repo -> IO Sha
-hashObject objtype content repo = getSha subcmd $ do
-	s <- pipeWriteRead (map Param params) content repo
-	return s
-	where
-		subcmd = "hash-object"
-		params = [subcmd, "-t", show objtype, "-w", "--stdin"]
+hashObject objtype content = hashObject' objtype (flip hPutStr content)
+
+hashObject' :: ObjectType -> (Handle -> IO ()) -> Repo -> IO Sha
+hashObject' objtype writer repo = getSha subcmd $
+	pipeWriteRead (map Param params) (Just writer) repo
+  where
+	subcmd = "hash-object"
+	params = [subcmd, "-t", show objtype, "-w", "--stdin", "--no-filters"]
