@@ -56,7 +56,7 @@ gen r u c gc = do
 			whereisKey = Nothing,
 			remoteFsck = Nothing,
 			repairRepo = Nothing,
-			config = M.empty,
+			config = c,
 			repo = r,
 			gitconfig = gc,
 			localpath = Just dir,
